pub enum Error {
InvalidSignature,
InvalidPublicKey,
InvalidSecretKey,
InvalidRecoveryId,
InvalidMessage,
InvalidInputLength,
TweakOutOfRange,
}
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool | 1.0.0 [src] |
This method tests for !=.
Performs copy-assignment from source. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static