SecretKey

Struct SecretKey 

pub struct SecretKey(/* private fields */);
Secret 256-bit key used as x in an ECDSA signature

Implementations

Source

impl SecretKey

pub fn as_ptr(&self) -> *const u8

Converts the object to a raw pointer for FFI interfacing

pub fn as_mut_ptr(&mut self) -> *mut u8

Converts the object to a mutable raw pointer for FFI interfacing

pub fn len(&self) -> usize

Returns the length of the object as an array

pub fn is_empty(&self) -> bool

Returns whether the object as an array is empty

Source

impl SecretKey

pub fn new<R: Rng>(secp: &Secp256k1, rng: &mut R) -> SecretKey

Creates a new random secret key

pub fn from_slice(secp: &Secp256k1, data: &[u8]) -> Result<SecretKey, Error>

Converts a SECRET_KEY_SIZE-byte slice to a secret key

pub fn add_assign( &mut self, secp: &Secp256k1, other: &SecretKey, ) -> Result<(), Error>

Adds one secret key to another, modulo the curve order

pub fn mul_assign( &mut self, secp: &Secp256k1, other: &SecretKey, ) -> Result<(), Error>

Multiplies one secret key by another, modulo the curve order

pub fn inv_assign(&mut self, secp: &Secp256k1) -> Result<(), Error>

Inverts (1 / self) this secret key.