[−][src]Struct secp256k1::RecoveryId
Tag used for public key recovery from signatures.
Methods
impl RecoveryId[src]
impl RecoveryIdTrait Implementations
impl Copy for RecoveryId[src]
impl Copy for RecoveryIdimpl Debug for RecoveryId[src]
impl Debug for RecoveryIdimpl PartialEq<RecoveryId> for RecoveryId[src]
impl PartialEq<RecoveryId> for RecoveryIdfn eq(&self, other: &RecoveryId) -> bool | [src] |
fn ne(&self, other: &RecoveryId) -> bool | [src] |
impl Eq for RecoveryId[src]
impl Eq for RecoveryIdimpl Clone for RecoveryId[src]
impl Clone for RecoveryIdfn clone(&self) -> RecoveryId | [src] |
fn clone_from(&mut self, source: &Self) | 1.0.0 [src] |
Performs copy-assignment from source. Read more
impl Into<u8> for RecoveryId[src]
impl Into<u8> for RecoveryIdimpl Into<i32> for RecoveryId[src]
impl Into<i32> for RecoveryIdAuto Trait Implementations
impl Send for RecoveryId
impl Send for RecoveryIdimpl Sync for RecoveryId
impl Sync for RecoveryIdBlanket Implementations
impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error> | [src] |
impl<T> From for T[src]
impl<T> From for Timpl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error> | [src] |
impl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T | [src] |
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId | [src] |
impl<T> Same for T[src]
impl<T> Same for Ttype Output = T
Should always be Self