Converts a "lax DER"-encoded byte slice to a signature. This is basically
only useful for validating signatures in the Bitcoin blockchain from before
- It should never be used in new applications. This library does not
support serializing to this "format"
Normalizes a signature to a "low S" form. In ECDSA, signatures are
of the form (r, s) where r and s are numbers lying in some finite
field. The verification equation will pass for (r, s) iff it passes
for (r, -s), so it is possible to ``modify'' signatures in transit
by flipping the sign of s. This does not constitute a forgery since
the signed message still cannot be changed, but for some applications,
changing even the signature itself can be a problem. Such applications
require a "strong signature". It is believed that ECDSA is a strong
signature except for this ambiguity in the sign of s, so to accommodate
these applications libsecp256k1 will only accept signatures for which
s is in the lower half of the field range. This eliminates the
ambiguity.
However, for some systems, signatures with high s-values are considered
valid. (For example, parsing the historic Bitcoin blockchain requires
this.) For these applications we provide this normalization function,
which ensures that the s value lies in the lower half of its range.
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static